Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(881)

Unified Diff: runtime/vm/class_finalizer.cc

Issue 412543003: Finalize the redirection type of a redirecting factory when the class of the (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/class_finalizer.cc
===================================================================
--- runtime/vm/class_finalizer.cc (revision 38465)
+++ runtime/vm/class_finalizer.cc (working copy)
@@ -1458,8 +1458,14 @@
name.ToCString(),
super_class_name.ToCString());
}
- // The function may be a still unresolved redirecting factory. Do not yet
- // try to resolve it in order to avoid cycles in class finalization.
+ if (function.IsRedirectingFactory()) {
+ // The function may be a still unresolved redirecting factory. Do not
+ // yet try to resolve it in order to avoid cycles in class finalization.
+ // However, the redirection type should be finalized.
+ Type& type = Type::Handle(function.RedirectionType());
+ type ^= FinalizeType(cls, type, kCanonicalize);
+ function.SetRedirectionType(type);
+ }
} else if (function.IsGetterFunction() ||
function.IsImplicitGetterFunction()) {
super_class = FindSuperOwnerOfFunction(cls, name);
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698